<?php
 /*
 #########################################################################
 #                       xt:Commerce  4.1 Shopsoftware
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 #
 # Copyright 2007-2014 xt:Commerce International Ltd. All Rights Reserved.
 # This file may not be redistributed in whole or significant part.
 # Content of this file is Protected By International Copyright Laws.
 #
 # ~~~~~~ xt:Commerce  4.1 Shopsoftware IS NOT FREE SOFTWARE ~~~~~~~
 #
 # http://www.xt-commerce.com
 #
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 #
 # @version $Id$
 # @copyright xt:Commerce International Ltd., www.xt-commerce.com
 #
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 #
 # xt:Commerce International Ltd., Kafkasou 9, Aglantzia, CY-2112 Nicosia
 #
 # office@xt-commerce.com
 #
 #########################################################################
 */

defined('_VALID_CALL') or die('Direct Access is not allowed.');

if (!class_exists('csv_pro_api', true))
	include_once _SRV_WEBROOT.'plugins/xt_pro_import/classes/class.csv_pro_api.php';
include_once _SRV_WEBROOT.'plugins/xt_pro_import/classes/class.xt_pro_import_fields_mapping.php';

class xt_pro_import_fields_settings extends xt_pro_import_fields_mapping {
	const SETTINGS_COLUMN_PRICE_INCL_TAX = 'setting_price_incl_tax';
	const SETTING_SHOW_FULL_PATH = 'setting_show_full_path';
	const SETTING_SHOW_NAME = 'setting_show_name';
	const SETTING_FILTER_CODE = 'setting_filter_code';
	
	/**
	 * Mapping with columns and their settings to be shown
	 * @var array
	 */
	public static $_fieldsHavingSettings = array(
		'products_price' => array(self::SETTINGS_COLUMN_PRICE_INCL_TAX),
		'products_image' => array(self::SETTING_SHOW_FULL_PATH),
		'manufacturers_id' => array(self::SETTING_SHOW_NAME),
		'categories_tree' => array(self::SETTING_SHOW_FULL_PATH),
	);
	
	/**
	 * Holds all columns from TABLE_PROIMPORTPLUGIN_FIELDS_MAPPING
	 * @var array
	 */
	protected $_tableColumns = array();
	
	/**
	 * (non-PHPdoc)
	 * @see xt_pro_import_fields_mapping::_getParams()
	 */
	function _getParams() {
		$api = new csv_pro_api();
		$tableColumns = $api->readTabelFields(TABLE_PROIMPORTPLUGIN_FIELDS_MAPPING);
		$this->_tableColumns = array_keys($tableColumns);
		
		$params['master_key']     = $this->_master_key;
		$params['default_sort']   = $this->_master_key;
		$params['SortField']      = $this->_master_key;
		$params['SortDir']        = "ASC";
	
		$obj = $this->_get($this->url_data['edit_id']);
		
		if ($obj->totalCount <> 1) die('Record not found');
		
		$field = $obj->data[0]['store_field'];
		
		//if (!isset(self::$_fieldsHavingSettings[$field])) die('This field does not have any settings');
		
		if (isset(self::$_fieldsHavingSettings[$field])) {
			// Show only settings for given type
			foreach (self::$_fieldsHavingSettings[$field] as $columnName) {
				$header[$columnName] = array('type' => 'dropdown', 'url'  => 'DropdownData.php?get=conf_truefalse');
			}
			// Hide not needed settings
			$exludedColumns = array_diff($this->_tableColumns, self::$_fieldsHavingSettings[$field]);
			
			foreach ($exludedColumns as $columnName) {
				$header[$columnName] = array('type' => 'hidden');
			}
		} else {
			foreach ($this->_tableColumns as $columnName) {
				$header[$columnName] = array('type' => 'hidden');
			}
		}
		// Filter code setting is always shown
		$header['setting_filter_code'] = array('type' => 'textarea');
		$params['header'] = $header;
		
		return $params;
	}
	
	/**
	 * Get value for column depending on settings set for this column
	 * @param string $columnName
	 * @param string $value
	 * @param array $settings
	 * @param array $recordData
	 * @return string
	 */
	public static function getValueForColumn($columnName, $value, $settings, $recordData) {
		global $price;
		
		// If there are no actual settings for this field just return the value
		//if (!isset(self::$_fieldsHavingSettings[$columnName]))
			//return $value;
		
		switch ($columnName) {
			case 'products_price':
				if ($settings[self::SETTINGS_COLUMN_PRICE_INCL_TAX] == 'true') {
					$value = $price->_BuildPrice($value, $recordData['products_tax_class_id'], 'show');
				}
				break;
			case 'products_image':
				if ($settings[self::SETTING_SHOW_FULL_PATH] == 'true' && !empty($value)) {
					$value = 'http://' . $_SERVER['HTTP_HOST'] . _SRV_WEB . 'media/images/org/' . $value;
				}
				break;
			case 'manufacturers_id':
				if ($settings[self::SETTING_SHOW_NAME] == 'true') {
					static $data = array();
					
					// Cache
					if (empty($data)) {
						$m = new manufacturer();
						$_data = $m->getManufacturerList('admin');
						foreach ($_data as $mdata) {
							$data[$mdata['manufacturers_id']] = $mdata['manufacturers_name'];
						}
					}
					
					$value = isset($data[$value]) ? $data[$value] : $value;
				}
				break;
			case 'categories_tree':
				if (!empty($recordData['categories']) && !empty($recordData['cat_tree_delimiter'])) {
					// Cache
					static $_categoryBranchCache = array();
					static $_categoryNames = array();
					
					// Explode categories to get main category
					$categries = explode($recordData['cat_tree_delimiter'], $recordData['categories']);
					$mainCategoryId = $categries[0];
					
					// Check settings
					if ($settings[self::SETTING_SHOW_FULL_PATH] == 'true') {
						// If there is no cache result, create one
						if (!isset($_categoryBranchCache[$mainCategoryId])) {
							$c = new category();
							$parentCategories = $c->getPath($mainCategoryId);
							// Main category will be first and top category will be last, flip the array
							$parentCategories = array_reverse($parentCategories);
							$barnch = array();
							foreach ($parentCategories as $categriyId) {
								// If there is no cached value cache it
								if (!isset($_categoryNames[$categriyId])) {
									$data = $c->getCategoryData($categriyId);
									$_categoryNames[$categriyId] = $data['categories_name'];
								}
								// Add to branch
								$barnch[] = $_categoryNames[$categriyId];
							}
							// Assign the value
							$_categoryBranchCache[$mainCategoryId] = join($recordData['cat_tree_delimiter'], $barnch);
						}
						$value = $_categoryBranchCache[$mainCategoryId];
					} else {
						// Just return main category Id. If there is no cached value cache it
						if (!isset($_categoryNames[$mainCategoryId])) {
							$c = new category();
							$data = $c->getCategoryData($mainCategoryId);
							$_categoryNames[$mainCategoryId] = $data['categories_name'];
						}
						$value = $_categoryNames[$mainCategoryId];
					}
				}
				break;
		}
		
		if (isset($settings[self::SETTING_FILTER_CODE]) && !empty($settings[self::SETTING_FILTER_CODE])) {
			@eval($settings[self::SETTING_FILTER_CODE]);
		}
		
		return $value;
	}
}